@@ -4,11 +4,12 @@ from simplejson import dumps, loads
 
 from django.conf import settings
 from django.contrib.auth.models import User, Permission
+from django.contrib.contenttypes.models import ContentType
 from django.db import connection
 from django.test import TestCase
 
 from slumber import Client
-from slumber.connector.ua import _calculate_signature
+from slumber.connector.ua import _calculate_signature, _fake_http_headers
 from slumber.scheme import SlumberServiceURLError
 from slumber_examples.models import Order, Pizza, PizzaPrice, Shop
 from slumber_examples.tests.configurations import ConfigureUser
@@ -20,9 +21,9 @@ def _perform(client, method, url, data, content_type=None, username=None):
         return client.get(*a, REQUEST_METHOD=method.upper(), **kw)
     logging.info("%s with data %s", method, data)
     headers = _calculate_signature('service',
-        method.upper(), url, data, username, True)
+        method.upper(), url, data, username)
     response = getattr(client, method, method_wrapper)(
-        url, data, content_type=content_type, **headers)
+        url, data, content_type=content_type, **_fake_http_headers(headers))
     if response.status_code == 200:
         return response, loads(response.content)
     else:
@@ -313,8 +314,7 @@ class BasicViews(ViewTests):
             identity=self.url('/slumber_examples/Shop/data/1/'),
             display='Test shop',
             operations=dict(
-                data=self.url('/slumber_examples/Shop/data/1/'),
-                delete=self.url('/slumber_examples/Shop/delete/1/'),
+                data='/slumber/pizzas/shop/%s/' % s.pk,
                 update=self.url('/slumber_examples/Shop/update/1/')),
             fields=dict(
                 id=dict(data=s.pk, kind='value', type='django.db.models.fields.AutoField'),
@@ -438,7 +438,7 @@ class BasicViewsService(ConfigureUser, BasicViews, ServiceTests, TestCase):
             "SELECT shop FROM slumber_examples_order WHERE id=%s",
             [order.pk])
         row = cursor.fetchone()
-        self.assertEquals(row[0], 'slumber://pizzas/slumber_examples/Shop/data/1/')
+        self.assertEquals(row[0], 'slumber://pizzas/shop/1/')
         order2 = Order.objects.get(pk=order.pk)
         self.assertEquals(unicode(order2.shop), unicode(order.shop))
         self.assertEquals(order2.shop.id, order.shop.id)
@@ -459,7 +459,7 @@ class BasicViewsWithServiceDirectory(ConfigureUser, BasicViews,
             [order.pk])
         row = cursor.fetchone()
         self.assertEquals(row[0],
-            'slumber://pizzas/slumber_examples/Shop/data/%s/' % shop.id)
+            'slumber://pizzas/shop/%s/' % shop.id)
         order2 = Order.objects.get(pk=order.pk)
         self.assertEquals(unicode(order2.shop), unicode(order.shop))
         self.assertEquals(order2.shop.id, order.shop.id)
@@ -477,6 +477,8 @@ class UserViews(ViewTests):
         self.user = User(username='test-user')
         self.user.set_password('password')
         self.user.save()
+        # The actual model doesn't matter so long as it is in auth
+        self.content_type = ContentType.objects.get(model='user')
         super(UserViews, self).setUp()
 
     def test_user_data(self):
@@ -522,8 +524,8 @@ class UserViews(ViewTests):
         self.assertEquals(json['permissions']['foo.example'], False, json)
 
     def test_user_permission_is_allowed(self):
-        permission = Permission(content_type_id=1, name='Can something',
-            codename='can_something')
+        permission = Permission(content_type=self.content_type,
+            name='Can something', codename='can_something')
         permission.save()
         self.user.user_permissions.add(permission)
         response, json = self.do_get(self.perm % (self.user.pk, 'auth.can_something'))
@@ -531,8 +533,8 @@ class UserViews(ViewTests):
         self.assertEquals(json['is-allowed'], True, json)
 
     def test_current_user_permission_is_allowed(self):
-        permission = Permission(content_type_id=1, name='Can something',
-            codename='can_something')
+        permission = Permission(content_type=self.content_type,
+            name='Can something', codename='can_something')
         permission.save()
         self.user.user_permissions.add(permission)
         response, json = self.do_get(self.user_perm % 'auth.can_something',
@@ -541,16 +543,16 @@ class UserViews(ViewTests):
         self.assertEquals(json['permissions']['auth.can_something'], True, json)
 
     def test_user_permission_not_allowed(self):
-        permission = Permission(content_type_id=1, name='Can something',
-            codename='can_something')
+        permission = Permission(content_type=self.content_type,
+            name='Can something', codename='can_something')
         permission.save()
         response, json = self.do_get(self.perm % (self.user.pk, 'auth.can_something'))
         self.assertEquals(response.status_code, 200)
         self.assertEquals(json['is-allowed'], False, json)
 
     def test_current_user_permission_not_allowed(self):
-        permission = Permission(content_type_id=1, name='Can something',
-            codename='can_something')
+        permission = Permission(content_type=self.content_type,
+            name='Can something', codename='can_something')
         permission.save()
         response, json = self.do_get(self.user_perm % 'auth.can_something',
                 username=self.user.username)
@@ -558,12 +560,12 @@ class UserViews(ViewTests):
         self.assertEquals(json['permissions']['auth.can_something'], False, json)
 
     def test_current_user_multiple_permissions(self):
-        can_perm = Permission(content_type_id=1, name='Can something',
-            codename='can_something')
+        can_perm = Permission(content_type=self.content_type,
+            name='Can something', codename='can_something')
         can_perm.save()
         self.user.user_permissions.add(can_perm)
-        cannot_perm = Permission(content_type_id=1, name='Cannot something',
-            codename='cannot_something')
+        cannot_perm = Permission(content_type=self.content_type,
+            name='Cannot something', codename='cannot_something')
         cannot_perm.save()
         response, json = self.do_get(self.user_perm_q,
             dict(q=['foo.example', 'auth.can_something', 'auth.cannot_something']),
